@@ -1,4 +1,5 @@
-def setup_navbar(app):
+def setup_navbar(app, positions):
+	app.navbarPositions = positions
 	app.navbarList = []
 	app.jinja_env.globals['getnavbar'] = lambda: [n for n in app.navbarList if n['visible']()]
 
@@ -7,9 +8,11 @@ def setup_navbar(app):
 # or 'fa'
 # ( see: http://fontawesome.io/icons/ )
 # visible is a function that returns "True" if this icon should be visible in the calling context
+# pylint: disable=too-many-arguments
 def register_navbar(name, iconlib='fa', icon=None, group=None, endpoint=None, blueprint=None, visible=None):
 	def wrapper(func):
 		def deferred_call(state):
+			assert blueprint
 			urlendpoint = endpoint
 			if not endpoint:
 				# pylint: disable=protected-access
@@ -26,20 +29,14 @@ def register_navbar(name, iconlib='fa', icon=None, group=None, endpoint=None, bl
 			item['name'] = name
 			item['blueprint'] = blueprint
 			item['visible'] = visible or (lambda: True)
-
+			item['position'] = 99
+			if blueprint.name in state.app.navbarPositions:
+				item['position'] = state.app.navbarPositions.index(blueprint.name)
+			else:
+				item['visible'] = lambda: False
 			state.app.navbarList.append(item)
-
-		if blueprint:
-			blueprint.record_once(deferred_call)
-		else:
-			class StateMock:
-				def __init__(self, app):
-					self.app = app
-			# pylint: disable=C0415
-			from flask import current_app
-			# pylint: enable=C0415
-			deferred_call(StateMock(current_app))
-
+			state.app.navbarList.sort(key=lambda item: item['position'])
+		blueprint.record_once(deferred_call)
 		return func
 
 	return wrapper
